==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/tr_tr/admin_responses.php <==
<?php
/**
 * Admin Responses
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminResponses.editcategory.field_submit'] = 'Güncelleme Kategorisi';
$lang['AdminResponses.editcategory.field_name'] = 'İsim';
$lang['AdminResponses.editcategory.boxtitle_editcategory'] = 'Güncelleme Kategorisi';
$lang['AdminResponses.editcategory.boxtitle_root'] = 'Kategori Düzenle';
$lang['AdminResponses.addcategory.field_submit'] = 'Kategori Oluştur';
$lang['AdminResponses.addcategory.field_name'] = 'İsim';
$lang['AdminResponses.addcategory.boxtitle_addcategory'] = 'Kategoriye Kategori Ekle [%1$s]';
$lang['AdminResponses.addcategory.boxtitle_root'] = 'Kategori Ekle';
$lang['AdminResponses.edit.field_submit'] = 'Güncelleme Yanıtı';
$lang['AdminResponses.edit.field_details'] = 'Yanıt Detayları';
$lang['AdminResponses.edit.field_name'] = 'İsim';
$lang['AdminResponses.edit.boxtitle_edit'] = 'Önceden Tanımlı Yanıtı Düzenle';
$lang['AdminResponses.add.field_submit'] = 'Yanıt Oluştur';
$lang['AdminResponses.add.field_details'] = 'Yanıt Detayları';
$lang['AdminResponses.add.field_name'] = 'İsim';
$lang['AdminResponses.add.boxtitle_add'] = 'Önceden Tanımlanmış Yanıtı [%1$s] Kategorisine Ekle';
$lang['AdminResponses.modal.delete_response'] = 'Bu ön tanımlı yanıtı silmek istediğinizden emin misiniz?';
$lang['AdminResponses.modal.delete_category'] = 'Bu kategoriyi silmek istediğinizden emin misiniz? Bu kategorideki tüm alt kategoriler ve önceden tanımlanmış yanıtlar ana kategoriye taşınacaktır.';
$lang['AdminResponses.index.no_responses'] = 'Bu bölümde herhangi bir yanıt bulunmamaktadır.';
$lang['AdminResponses.index.delete'] = 'Silme';
$lang['AdminResponses.index.edit'] = 'Düzenle';
$lang['AdminResponses.index.text_up_level'] = 'Bir Seviye Yukarı Çıkın';
$lang['AdminResponses.index.add_category'] = 'Buraya Kategori Ekle';
$lang['AdminResponses.index.add_response'] = 'Yanıtı Buraya Ekleyin';
$lang['AdminResponses.index.boxtitle_responses'] = 'Önceden Tanımlanmış Yanıtlar';
$lang['AdminResponses.!text.closed_parenthesis'] = ')';
$lang['AdminResponses.!text.forward_slash'] = '/';
$lang['AdminResponses.!text.open_parenthesis'] = '(';
$lang['AdminResponses.editcategory.page_title'] = 'Destek Yöneticisi > Kategoriyi Düzenle';
$lang['AdminResponses.addcategory.page_title'] = 'Destek Yöneticisi > Kategori Ekle';
$lang['AdminResponses.edit.page_title'] = 'Destek Yöneticisi > Önceden Tanımlanmış Yanıtı Düzenle';
$lang['AdminResponses.add.page_title'] = 'Destek Yöneticisi > Önceden Tanımlı Yanıt Ekle';
$lang['AdminResponses.index.page_title'] = 'Destek Yöneticisi > Önceden Tanımlanmış Yanıtlar';
$lang['AdminResponses.!success.response_deleted'] = '1$s yanıtı başarıyla silindi.';
$lang['AdminResponses.!success.response_updated'] = '1$s yanıtı başarıyla güncellendi.';
$lang['AdminResponses.!success.response_added'] = '1$s yanıtı başarıyla eklendi.';
$lang['AdminResponses.!success.category_deleted'] = '1$s kategorisi başarıyla silindi.';
$lang['AdminResponses.!success.category_updated'] = '1$s kategorisi başarıyla güncellendi.';
$lang['AdminResponses.!success.category_added'] = '1$s kategorisi başarıyla eklendi.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/tr_tr/admin_responses.php <==
<?php
/**
 * Admin Responses
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminResponses.editcategory.field_submit'] = 'Güncelleme Kategorisi';
$lang['AdminResponses.editcategory.field_name'] = 'İsim';
$lang['AdminResponses.editcategory.boxtitle_editcategory'] = 'Güncelleme Kategorisi';
$lang['AdminResponses.editcategory.boxtitle_root'] = 'Kategori Düzenle';
$lang['AdminResponses.addcategory.field_submit'] = 'Kategori Oluştur';
$lang['AdminResponses.addcategory.field_name'] = 'İsim';
$lang['AdminResponses.addcategory.boxtitle_addcategory'] = 'Kategoriye Kategori Ekle [%1$s]';
$lang['AdminResponses.addcategory.boxtitle_root'] = 'Kategori Ekle';
$lang['AdminResponses.edit.field_submit'] = 'Güncelleme Yanıtı';
$lang['AdminResponses.edit.field_details'] = 'Yanıt Detayları';
$lang['AdminResponses.edit.field_name'] = 'İsim';
$lang['AdminResponses.edit.boxtitle_edit'] = 'Önceden Tanımlı Yanıtı Düzenle';
$lang['AdminResponses.add.field_submit'] = 'Yanıt Oluştur';
$lang['AdminResponses.add.field_details'] = 'Yanıt Detayları';
$lang['AdminResponses.add.field_name'] = 'İsim';
$lang['AdminResponses.add.boxtitle_add'] = 'Önceden Tanımlanmış Yanıtı [%1$s] Kategorisine Ekle';
$lang['AdminResponses.modal.delete_response'] = 'Bu ön tanımlı yanıtı silmek istediğinizden emin misiniz?';
$lang['AdminResponses.modal.delete_category'] = 'Bu kategoriyi silmek istediğinizden emin misiniz? Bu kategorideki tüm alt kategoriler ve önceden tanımlanmış yanıtlar ana kategoriye taşınacaktır.';
$lang['AdminResponses.index.no_responses'] = 'Bu bölümde herhangi bir yanıt bulunmamaktadır.';
$lang['AdminResponses.index.delete'] = 'Silme';
$lang['AdminResponses.index.edit'] = 'Düzenle';
$lang['AdminResponses.index.text_up_level'] = 'Bir Seviye Yukarı Çıkın';
$lang['AdminResponses.index.add_category'] = 'Buraya Kategori Ekle';
$lang['AdminResponses.index.add_response'] = 'Yanıtı Buraya Ekleyin';
$lang['AdminResponses.index.boxtitle_responses'] = 'Önceden Tanımlanmış Yanıtlar';
$lang['AdminResponses.!text.closed_parenthesis'] = ')';
$lang['AdminResponses.!text.forward_slash'] = '/';
$lang['AdminResponses.!text.open_parenthesis'] = '(';
$lang['AdminResponses.editcategory.page_title'] = 'Destek Yöneticisi > Kategoriyi Düzenle';
$lang['AdminResponses.addcategory.page_title'] = 'Destek Yöneticisi > Kategori Ekle';
$lang['AdminResponses.edit.page_title'] = 'Destek Yöneticisi > Önceden Tanımlanmış Yanıtı Düzenle';
$lang['AdminResponses.add.page_title'] = 'Destek Yöneticisi > Önceden Tanımlı Yanıt Ekle';
$lang['AdminResponses.index.page_title'] = 'Destek Yöneticisi > Önceden Tanımlanmış Yanıtlar';
$lang['AdminResponses.!success.response_deleted'] = 'Yanıt %1$s başarıyla silindi.';
$lang['AdminResponses.!success.response_updated'] = 'Yanıt %1$s başarıyla güncellendi.';
$lang['AdminResponses.!success.response_added'] = 'Yanıt %1$s başarıyla eklendi.';
$lang['AdminResponses.!success.category_deleted'] = 'Kategori %1$s başarıyla silindi.';
$lang['AdminResponses.!success.category_updated'] = 'Kategori %1$s başarıyla güncellendi.';
$lang['AdminResponses.!success.category_added'] = 'Kategori %1$s başarıyla eklendi.';
